==> x-ui-vue3-0.2.2.tgz: package/cjs/table/index.js <==
'use strict';

var vue = require('vue');
var _interface = require('./interface.js');
var TableHeader = require('./TableHeader.js');
var TableBody = require('./TableBody.js');

const tableProps = {
  prefixCls: {
    default: "x-table"
  },
  columns: Array,
  data: Array,
  rowProps: Function,
  maxHeight: Number,
  rowClass: [String, Function],
  bordered: Boolean,
  bottomBordered: {
    default: true
  },
  scrollX: Number,
  virtualScroll: Boolean,
  size: {
    type: String,
    default: "medium"
  }
};
const Table = vue.defineComponent({
  name: "x-table",
  props: tableProps,
  setup(props, {
    slots
  }) {
    const headerRef = vue.ref();
    const bodyRef = vue.ref();
    const leftFixedColumsRef = vue.computed(() => {
      var _a;
      return (_a = props.columns) == null ? void 0 : _a.filter((col) => col.fixed === "left");
    });
    const rightFixedColumsRef = vue.computed(() => {
      var _a;
      return (_a = props.columns) == null ? void 0 : _a.filter((col) => col.fixed === "right");
    });
    const fixedColumnLeftMapRef = vue.computed(() => {
      let left = 0;
      return leftFixedColumsRef.value.reduce((map, col) => (map[col.key] = left, left += col.width || 0, map), {});
    });
    const fixedColumnRightMapRef = vue.computed(() => {
      let right = 0;
      return rightFixedColumsRef.value.reverse().reduce((map, col) => (map[col.key] = right, right += col.width || 0, map), {});
    });
    let scrollType = "";
    let lastLeft = 0;
    function onHeaderScroll(el) {
      scrollType = "header";
      syncScroll(el);
    }
    function onBodyScroll(el) {
      scrollType = "body";
      syncScroll(el);
    }
    function syncScroll(el) {
      if (el.target.scrollLeft == lastLeft)
        return;
      lastLeft = el.target.scrollLeft;
      if (scrollType === "header") {
        ;
        bodyRef.value.$el.scrollLeft = lastLeft;
      } else {
        if (!headerRef.value)
          return;
        headerRef.value.$el.scrollLeft = lastLeft;
      }
    }
    vue.provide(_interface.dataTableContextKey, {
      props,
      leftFixedColumsRef,
      rightFixedColumsRef,
      fixedColumnLeftMapRef,
      fixedColumnRightMapRef
    });
    return () => {
      const {
        prefixCls,
        maxHeight,
        bordered,
        bottomBordered
      } = props;
      const scrollable = !!maxHeight;
      const cls = [prefixCls, bordered && `${prefixCls}-bordered`, bottomBordered && `${prefixCls}-bottom-bordered`];
      return vue.createVNode("div", {
        "class": cls
      }, [scrollable && vue.createVNode(TableHeader, {
        "discrete": true,
        "ref": headerRef,
        "onScroll": onHeaderScroll
      }, null), vue.createVNode(TableBody, {
        "showHeader": !scrollable,
        "ref": bodyRef,
        "onScroll": onBodyScroll
      }, slots)]);
    };
  }
});
Table.install = (app) => {
  app.component(Table.name, Table);
};

module.exports = Table;

==> x-ui-vue3-0.2.3.tgz: package/cjs/table/index.js <==
'use strict';

var vue = require('vue');
var _interface = require('./interface.js');
var TableHeader = require('./TableHeader.vue.js');
var TableBody = require('./TableBody.js');

const tableProps = {
  prefixCls: {
    default: "x-table"
  },
  columns: Array,
  data: Array,
  rowProps: Function,
  maxHeight: Number,
  rowClass: [String, Function],
  bordered: Boolean,
  bottomBordered: {
    default: true
  },
  scrollX: Number,
  virtualScroll: Boolean,
  size: {
    type: String,
    default: "medium"
  }
};
const Table = vue.defineComponent({
  name: "x-table",
  props: tableProps,
  setup(props, {
    slots
  }) {
    const headerRef = vue.ref();
    const bodyRef = vue.ref();
    const leftFixedColumsRef = vue.computed(() => {
      var _a;
      return (_a = props.columns) == null ? void 0 : _a.filter((col) => col.fixed === "left");
    });
    const rightFixedColumsRef = vue.computed(() => {
      var _a;
      return (_a = props.columns) == null ? void 0 : _a.filter((col) => col.fixed === "right");
    });
    const fixedColumnLeftMapRef = vue.computed(() => {
      let left = 0;
      return leftFixedColumsRef.value.reduce((map, col) => (map[col.key] = left, left += col.width || 0, map), {});
    });
    const fixedColumnRightMapRef = vue.computed(() => {
      let right = 0;
      return rightFixedColumsRef.value.reverse().reduce((map, col) => (map[col.key] = right, right += col.width || 0, map), {});
    });
    let lastLeft = 0;
    function onHeaderScroll(e) {
      syncScroll(e, true);
    }
    function onBodyScroll(e) {
      syncScroll(e, false);
    }
    function syncScroll(e, header) {
      if (e.target.scrollLeft == lastLeft)
        return;
      lastLeft = e.target.scrollLeft;
      if (header) {
        ;
        bodyRef.value.$el.scrollLeft = lastLeft;
      } else {
        if (!headerRef.value)
          return;
        headerRef.value.$el.scrollLeft = lastLeft;
      }
    }
    vue.provide(_interface.dataTableContextKey, {
      props,
      leftFixedColumsRef,
      rightFixedColumsRef,
      fixedColumnLeftMapRef,
      fixedColumnRightMapRef
    });
    return () => {
      const {
        prefixCls,
        bordered,
        bottomBordered
      } = props;
      const cls = [prefixCls, bordered && `${prefixCls}-bordered`, bottomBordered && `${prefixCls}-bottom-bordered`];
      return vue.createVNode("div", {
        "class": cls
      }, [vue.createVNode(TableHeader, {
        "ref": headerRef,
        "onScroll": onHeaderScroll
      }, null), vue.createVNode(TableBody, {
        "ref": bodyRef,
        "onScroll": onBodyScroll
      }, slots)]);
    };
  }
});
Table.install = (app) => {
  app.component(Table.name, Table);
};

module.exports = Table;
